@@ -48,7 +48,7 @@ def acfun_download(url, output_dir = '.', merge = True, info_only = False):
     assert re.match(r'http://www.acfun.tv/v/ac(\d+)', url)
     html = get_html(url)
     
-    title = r1(r'<h1 id="title-article" class="title"[^<>]*>([^<>]+)<span', html)
+    title = r1(r'<h1 id="title-article" class="title"[^<>]*>([^<>]+)<', html)
     assert title
     title = unescape_html(title)
     title = escape_file_path(title)
